# lrose-solo-python
Python interface to Solo editing functions

To install, type this in shell: 

```shell
pip install -i https://test.pypi.org/simple/ pysolo-wip
```
Tested for Windows 10 and Ubuntu 18.04 and 20.04.

Test it on Colab: https://colab.research.google.com/drive/1q2n79rtTjvQahCaFI9sBEGgveOm6HL7V?usp=sharing
